execpath

package
v0.0.0-...-33893c2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 19, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

Package execpath resolves executable names without consulting the process PATH.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Command

func Command(name string, args ...string) (*exec.Cmd, error)

Command builds a command whose executable is resolved from fixed system directories.

func Find

func Find(name string) (string, error)

Find resolves name to an executable path from fixed system directories.

func RunWithTimeout

func RunWithTimeout(cmd *exec.Cmd, timeout time.Duration) error

RunWithTimeout runs cmd and kills it if timeout elapses before it exits.

Types

This section is empty.

Jump to